@@ -1,5 +1,4 @@
-from bgameb.markers import Step
-from bgameb.items import Dice, Card
+from bgameb.items import Dice, Card, Step
 from bgameb.tools import Shaker, Deck, Steps
 from bgameb.players import Player
 from bgameb.game import Game
